module License.Hippocratic exposing
  ( Module
  , info
  )

import License exposing
  ( DownloadType
  , LicenseInfo
  , ModuleInfo
  )
import Html exposing (text)
import Html exposing (a)
import Html.Attributes exposing (href)

info : LicenseInfo Module
info =
  { availableModules = availableModules
  , templates = getTemplate
  , moduleInfo = moduleInfo
  , descriptors =
    { name = "Hippocratic License 3.0"
    , slug = "HL"
    , desc = String.trim """
The flagship ethical source license, the Hippocratic license is one of the most customizable and practical ELOS licenses out there.  The 3rd version features many optional modules to tailor the license to issues that matter to you, including optional copyleft functionality.

Also featured is an out-of-court arbitration clause, and restrictions that prevent any organizations involved in unethical practices from using the software, as opposed to just preventing the direct use of the software for unethical practices.
"""
    }
  }

type Module
  = CarbonUnderground
  | Ecocide
  | Extractive
  | BDS
  | Taliban
  | Myanmar
  | XinjiangUygar
  | UsTariff
  | Surveillance
  | Military
  | LawEnforcement
  | Media
  | SocialAuditing
  | BoardOfDirectors
  | SupplyChain
  | Copyleft

availableModules : List Module
availableModules =
  [ CarbonUnderground
  , Ecocide
  , Extractive
  , BDS
  , Taliban
  , Myanmar
  , XinjiangUygar
  , UsTariff
  , Surveillance
  , Military
  , LawEnforcement
  , Media
  , SocialAuditing
  , BoardOfDirectors
  , SupplyChain
  , Copyleft
  ]

moduleInfo : Module -> ModuleInfo
moduleInfo mod = case mod of
  CarbonUnderground ->
    { name = "Carbon Underground 200"
    , desc =
      [ text (String.trim """
Disallow use by the top global publicly-owned coal, oil, and gas reserve (judged by
""")
      , text " "
      , a
        [ href "https://www.ffisolutions.com/research-analytics-index-solutions/research-screening/the-carbon-underground-200/"
        ]
        [ text "the FFI Carbon Underground 200" ]
      , text ")"
      ]
    , index = 0
    }
  Ecocide ->
    { name = "Ecocide"
    , desc = [text "Disallow anyone who knowingly commits widespread or long term ecocide"]
    , index = 1
    }
  Extractive ->
    { name = "Extractive Industries"
    , desc =
      [text (String.trim """
Disallow use by anyone involved in fossil fuel / mineral exploitation, extraction, development, and sale
""")
      ]
    , index = 2
    }
  BDS ->
    { name = "BDS (Boycott, Divestment, Sanctions)"
    , desc =
      [ text "Disallow use by anyone on the "
      , a
        [ href "https://bdsmovement.net/" ]
        [ text "Boycott, Divestment, Sanctions'" ]
      , text " list"
      ]
    , index = 3
    }
  Taliban ->
    { name = "Taliban"
    , desc = [text "Disallow use by anyone who trades with, works with, or is the Taliban"]
    , index = 4
    }
  Myanmar ->
    { name = "Myanmar"
    , desc =
      [ text (String.trim """
Disallow use by anyone who trades with, works with, or is the Myanmar/Burmese military
""")
      ]
    , index = 5
    }
  XinjiangUygar ->
    { name = "Xinjiang Uygur Autonomous Region"
    , desc =
      [ text (String.trim """
Disallow use by anyone who works with or is someone who benefits from goods produced in the Xinjiang Uygur Autonomous Region of China
""")
      ]
    , index = 6
    }
  UsTariff ->
    { name = "U.S. Tariff Act"
    , desc =
      [ text (String.trim """
Disallow use by anyone who works with or is someone who the U.S. Customs and Border Protection believes uses forced labor
""")
      ]
    , index = 7
    }
  Surveillance ->
    { name = "Mass Surveillance"
    , desc =
      [ text (String.trim """
Disallow use by anyone who works with or is a government/multinational corporation who participates in a mass-surveillance program
""")
      ]
    , index = 8
    }
  Military ->
    { name = "Military Activities"
    , desc =
      [ text (String.trim """
Disallow use by anyone who works with or is a government/multinational corporation who conducts military activities
""")
      ]
    , index = 9
    }
  LawEnforcement ->
    { name = "Law Enforcement"
    , desc =
      [ text (String.trim """
Disallow use by anyone who works with or anyone who trades with or offers support to local, state, or federal law enforcement
""")
      ]
    , index = 10
    }
  Media ->
    { name = "Media"
    , desc =
      [ text (String.trim """
Disallow use by anyone who is or works with someone who broadcasts messages promoting violence
""")
      ]
    , index = 11
    }
  SocialAuditing ->
    { name = "Social Auditing"
    , desc =
      [ text (String.trim """
Require that organizations that use your software only use social auditing methods that adhere to the principles of the
""")
      , text " "
      , a
        [ href "https://wsr-network.org/what-is-wsr/statement-of-principles/" ]
        [ text "Worker-Driven Social Responsibility Network" ]
      , text ", or not use social auditing methods at all"
      ]
    , index = 12
    }
  BoardOfDirectors ->
    { name = "Workers on Board of Directors"
    , desc =
      [ text (String.trim """
If the organization using your software has a board of directors, require that they have
at least 30% of the seats on the board be paid less than twice the amount of the lowest paid worker in the organization
""")
      ]
    , index = 13
    }
  SupplyChain ->
    { name = "Supply Chain Transparency"
    , desc =
      [ text (String.trim """
Require that whoever uses your software must publish information about their supply chain on a public website
""")
      ]
    , index = 14
    }
  Copyleft ->
    { name = "Copyleft"
    , desc =
      [ text (String.trim """
Require that any modifications or derivative works based on your software or source code be licensed under the exact same license
""")
      ]
    , index = 15
    }

getTemplate : DownloadType -> List (Maybe Module, String)
getTemplate _ = [ (Nothing,
 """
**HIPPOCRATIC LICENSE**

  **Version 3.0, October 2021**

  **TERMS AND CONDITIONS**

TERMS AND CONDITIONS FOR USE, COPY, MODIFICATION, PREPARATION OF DERIVATIVE WORK, REPRODUCTION, AND DISTRIBUTION:

1.  **DEFINITIONS:**

  *This section defines certain terms used throughout this license agreement.*

  1.1.  "License" means the terms and conditions, as stated herein, for use, copy, modification, preparation of derivative work, reproduction, and distribution of Software (as defined below).

  1.2.  "Licensor" means the copyright and/or patent owner or entity authorized by the copyright and/or patent owner that is granting the License.

  1.3.  "Licensee" means the individual or entity exercising permissions granted by this License, including the use, copy, modification, preparation of derivative work, reproduction, and distribution of Software (as defined below).

  1.4.  "Software" means any copyrighted work, including but not limited to software code, authored by Licensor and made available under this License.

  1.5.  "Supply Chain" means the sequence of processes involved in the production and/or distribution of a commodity, good, or service offered by the Licensee.

  1.6.  "Supply Chain Impacted Party" or "Supply Chain Impacted Parties" means any person(s) directly impacted by any of Licensee's Supply Chain, including the practices of all persons or entities within the Supply Chain prior to a good or service reaching the Licensee.

  1.7.  "Duty of Care" is defined by its use in tort law, delict law, and/or similar bodies of law closely related to tort and/or delict law, including without limitation, a requirement to act with the watchfulness, attention, caution, and prudence that a reasonable person in the same or similar circumstances would use towards any Supply Chain Impacted Party.

  1.8.  "Worker" is defined to include any and all permanent, temporary, and agency workers, as well as piece-rate, salaried, hourly paid, legal young (minors), part-time, night, and migrant workers.

2.  **INTELLECTUAL PROPERTY GRANTS:**

  *This section identifies intellectual property rights granted to a Licensee*.

  2.1.  *Grant of Copyright License*: Subject to the terms and conditions of this License, Licensor hereby grants to Licensee a worldwide, non-exclusive, no-charge, royalty-free copyright license to use, copy, modify, prepare derivative work, reproduce, or distribute the Software, Licensor authored modified software, or other work derived from the Software.

  2.2  *Grant of Patent License*: Subject to the terms and conditions of this License, Licensor hereby grants Licensee a worldwide, non-exclusive, no-charge, royalty-free patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer Software.

3.  **ETHICAL STANDARDS:**

  *This section lists conditions the Licensee must comply with in order to have rights under this License.*

  The rights granted to the Licensee by this License are expressly made subject to the Licensee's ongoing compliance with the following conditions:

  3.1.  The Licensee SHALL NOT, whether directly or indirectly, through agents or assigns:

    3.1.1.  Infringe upon any person's right to life or security of person, engage in extrajudicial killings, or commit murder, without lawful cause
    (See Article 3, *United Nations Universal Declaration of Human Rights*; Article 6, *International Covenant on Civil and Political Rights*)

    3.1.2.  Hold any person in slavery, servitude, or forced labor
    (See Article 4, *United Nations Universal Declaration of Human Rights*; Article 8, *International Covenant on Civil and Political Rights*);

    3.1.3.  Contribute to the institution of slavery, slave trading, forced labor, or unlawful child labor
    (See Article 4, *United Nations Universal Declaration of Human Rights*; Article 8, *International Covenant on Civil and Political Rights*);

    3.1.4.  Torture or subject any person to cruel, inhumane, or degrading treatment or punishment
    (See Article 5, *United Nations Universal Declaration of Human Rights*; Article 7, *International Covenant on Civil and Political Rights*);

    3.1.5.  Discriminate on the basis of sex, gender, sexual orientation, race, ethnicity, nationality, religion, caste, age, medical disability or impairment, and/or any other like circumstances
    (See Article 7, *United Nations Universal Declaration of Human Rights*; Article 2, *International Covenant on Economic, Social and Cultural Rights*; Article 26, *International Covenant on Civil and Political Rights*);

    3.1.6.  Prevent any person from exercising his/her/their right to seek an effective remedy by a competent court or national tribunal (including domestic judicial systems, international courts, arbitration bodies, and other adjudicating bodies) for actions violating the fundamental rights granted to him/her/them by applicable constitutions, applicable laws, or by this License
    (See Article 8, *United Nations Universal Declaration of Human Rights*; Articles 9 and 14, *International Covenant on Civil and Political Rights*);

    3.1.7.  Subject any person to arbitrary arrest, detention, or exile
    (See Article 9, *United Nations Universal Declaration of Human Rights*; Article 9, *International Covenant on Civil and Political Rights*);

    3.1.8.  Subject any person to arbitrary interference with a person's privacy, family, home, or correspondence without the express written consent of the person
    (See Article 12, *United Nations Universal Declaration of Human Rights*; Article 17, *International Covenant on Civil and Political Rights*);

    3.1.9.  Arbitrarily deprive any person of his/her/their property
    (See Article 17, *United Nations Universal Declaration of Human Rights*);

    3.1.10. Forcibly remove indigenous peoples from their lands or territories or take any action with the aim or effect of dispossessing indigenous peoples from their lands, territories, or resources, including without limitation the intellectual property or traditional knowledge of indigenous peoples, without the free, prior, and informed consent of indigenous peoples concerned
    (See Articles 8 and 10, *United Nations Declaration on the Rights of Indigenous Peoples*);
"""), (Just CarbonUnderground,
 """
    3.1.11. (Module -- Carbon Underground 200) Be an individual or entity, or a representative, agent, affiliate, successor, attorney, or assign of an individual or entity, on the FFI Solutions Carbon Underground 200 list;
"""), (Just Ecocide,
 """
    3.1.12. (Module -- Ecocide) Commit ecocide:

      3.1.12.1  For the purpose of this section, "ecocide" means unlawful or wanton acts committed with knowledge that there is a substantial likelihood of severe and either widespread or long-term damage to the environment being caused by those acts;

      3.1.12.2  For the purpose of further defining ecocide and the terms contained in the previous paragraph:

        3.1.12.2.1.  "Wanton" means with reckless disregard for damage which would be clearly excessive in relation to the social and economic benefits anticipated;

        3.1.12.2.2.  "Severe" means damage which involves very serious adverse changes, disruption, or harm to any element of the environment, including grave impacts on human life or natural, cultural, or economic resources;

        3.1.12.2.3.  "Widespread" means damage which extends beyond a limited geographic area, crosses state boundaries, or is suffered by an entire ecosystem or species or a large number of human beings;

        3.1.12.2.4.  "Long-term" means damage which is irreversible or which cannot be redressed through natural recovery within a reasonable period of time; and

        3.1.12.2.5.  "Environment" means the earth, its biosphere, cryosphere, lithosphere, hydrosphere, and atmosphere, as well as outer space

			(See Section II, *Independent Expert Panel for the Legal Definition of Ecocide*, Stop Ecocide Foundation and the Promise Institute for Human Rights at UCLA School of Law, June 2021);
"""), (Just Extractive,
 """
    3.1.13. (Module -- Extractive Industries) Be an individual or entity, or a representative, agent, affiliate, successor, attorney, or assign of an individual or entity, that engages in fossil fuel or mineral exploration, extraction, development, or sale;
"""), (Just BDS,
 """
    3.1.14. (Module -- BDS) Be an individual or entity, or a representative, agent, affiliate, successor, attorney, or assign of an individual or entity, identified by the Boycott, Divestment, Sanctions ("BDS") movement on its website ([https://bdsmovement.net/](https://bdsmovement.net/) and [https://bdsmovement.net/get-involved/what-to-boycott](https://bdsmovement.net/get-involved/what-to-boycott)) as a target for boycott;
"""), (Just Taliban,
 """
    3.1.15. (Module -- Taliban) Be an individual or entity that:

      3.1.15.1.  engages in any commercial transactions with the Taliban; or

      3.1.15.2.  is a representative, agent, affiliate, successor, attorney, or assign of the Taliban;
"""), (Just Myanmar,
 """
    3.1.16. (Module -- Myanmar) Be an individual or entity that:

      3.1.16.1.  engages in any commercial transactions with the Myanmar/Burmese military junta; or

      3.1.16.2.  is a representative, agent, affiliate, successor, attorney, or assign of the Myanmar/Burmese government;
"""), (Just XinjiangUygar,
 """
    3.1.17. (Module -- Xinjiang Uygur Autonomous Region) Be an individual or entity, or a representative, agent, affiliate, successor, attorney, or assign of any individual or entity, that does business in, purchases goods from, or otherwise benefits from goods produced in the Xinjiang Uygur Autonomous Region of China;
"""), (Just UsTariff,
 """
    3.1.18. (Module -- U.S. Tariff Act) Be an individual or entity:

      3.1.18.1.  which U.S. Customs and Border Protection (CBP) has currently issued a Withhold Release Order (WRO) or finding against based on reasonable suspicion of forced labor; or

      3.1.18.2.  that is a representative, agent, affiliate, successor, attorney, or assign of an individual or entity that does business with an individual or entity which currently has a WRO or finding from CBP issued against it based on reasonable suspicion of forced labor;
"""), (Just Surveillance,
 """
    3.1.19. (Module -- Mass Surveillance) Be a government agency or multinational corporation, or a representative, agent, affiliate, successor, attorney, or assign of a government or multinational corporation, which participates in mass surveillance programs;
"""), (Just Military,
 """
    3.1.20. (Module -- Military Activities) Be an entity or a representative, agent, affiliate, successor, attorney, or assign of an entity which conducts military activities;
"""), (Just LawEnforcement,
 """
    3.1.21. (Module -- Law Enforcement) Be an individual or entity, or a or a representative, agent, affiliate, successor, attorney, or assign of an individual or entity, that provides good or services to, or otherwise enters into any commercial contracts with, any local, state, or federal law enforcement agency;
"""), (Just Media,
 """
    3.1.22. (Module -- Media) Be an individual or entity, or a or a representative, agent, affiliate, successor, attorney, or assign of an individual or entity, that broadcasts messages promoting killing, torture, or other forms of extreme violence;
"""), (Nothing,
 """
    3.1.23. Interfere with Workers' free exercise of the right to organize and associate
    (See Article 20, United Nations Universal Declaration of Human Rights; C087 - Freedom of Association and Protection of the Right to Organise Convention, 1948 (No. 87), International Labour Organization; Article 8, International Covenant on Economic, Social and Cultural Rights); and

    3.1.24. Harm the environment in a manner inconsistent with local, state, national, or international law.

  3.2.  The Licensee SHALL:
"""), (Just SocialAuditing,
 """
    3.2.1.  (Module -- Social Auditing) Only use social auditing mechanisms that adhere to Worker-Driven Social Responsibility Network's Statement of Principles (https://wsr-network.org/what-is-wsr/statement-of-principles/) over traditional social auditing mechanisms, to the extent the Licensee uses any social auditing mechanisms at all;
"""), (Just BoardOfDirectors,
 """
    3.2.2.  (Module -- Workers on Board of Directors) Ensure that if the Licensee has a Board of Directors, 30% of Licensee's board seats are held by Workers paid no more than 200% of the compensation of the lowest paid Worker of the Licensee;
"""), (Just SupplyChain,
 """
    3.2.3.  (Module -- Supply Chain Transparency) Provide clear, accessible supply chain data to the public in accordance with the following conditions:

      3.2.3.1.  All data will be on Licensee's website and/or, to the extent Licensee is a representative, agent, affiliate, successor, attorney, subsidiary, or assign, on Licensee's principal's or parent's website or some other online platform accessible to the public via an internet search on a common internet search engine; and

      3.2.3.2.  Data published will include, where applicable, manufacturers, top tier suppliers, subcontractors, cooperatives, component parts producers, and farms;
"""), (Nothing,
 """
    3.2.4.  Provide equal pay for equal work where the performance of such work requires equal skill, effort, and responsibility, and which are performed under similar working conditions, except where such payment is made pursuant to:

      3.2.4.1.  A seniority system;

      3.2.4.2.  A merit system;

      3.2.4.3.  A system which measures earnings by quantity or quality of production; or

      3.2.4.4.  A differential based on any other factor other than sex, gender, sexual orientation, race, ethnicity, nationality, religion, caste, age, medical disability or impairment, and/or any other like circumstances
      (See 29 U.S.C.A. section 206(d)(1); Article 23, *United Nations Universal Declaration of Human Rights*; Article 7, *International Covenant on Economic, Social and Cultural Rights*; Article 26, *International Covenant on Civil and Political Rights*); and

    3.2.5.  Allow for reasonable limitation of working hours and periodic holidays with pay
    (See Article 24, *United Nations Universal Declaration of Human Rights*; Article 7, *International Covenant on Economic, Social and Cultural Rights*).

4.  **SUPPLY CHAIN IMPACTED PARTIES:**

  *This section identifies additional individuals or entities that a Licensee could harm as a result of violating the Ethical Standards section, the condition that the Licensee must voluntarily accept a Duty of Care for those individuals or entities, and the right to a private right of action that those individuals or entities possess as a result of violations of the Ethical Standards section.*

    4.1.  In addition to the above Ethical Standards, Licensee voluntarily accepts a Duty of Care for Supply Chain Impacted Parties of this License, including individuals and communities impacted by violations of the Ethical Standards. The Duty of Care is breached when a provision within the Ethical Standards section is violated by a Licensee, one of its successors or assigns, or by an individual or entity that exists within the Supply Chain prior to a good or service reaching the Licensee.

    4.2.  Breaches of the Duty of Care, as stated within this section, shall create a private right of action, allowing any Supply Chain Impacted Party harmed by the Licensee to take legal action against the Licensee in accordance with applicable negligence laws, whether they be in tort law, delict law, and/or similar bodies of law closely related to tort and/or delict law, regardless if Licensee is directly responsible for the harms suffered by a Supply Chain Impacted Party. Nothing in this section shall be interpreted to include acts committed by individuals outside of the scope of his/her/their employment.

5.  **NOTICE:**
  *This section explains when a Licensee must notify others of the License.*

  5.1.  *Distribution of Notice*: Licensee must ensure that everyone who receives a copy of or uses any part of Software from Licensee, with or without changes, also receives the License and the copyright notice included with Software (and if included by the Licensor, patent, trademark, and attribution notice). Licensee must ensure that License is prominently displayed so that any individual or entity seeking to download, copy, use, or otherwise receive any part of Software from Licensee is notified of this License and its terms and conditions. Licensee must cause any modified versions of the Software to carry prominent notices stating that Licensee changed the Software.

  5.2.  *Modified Software*: Licensee is free to create modifications of the Software and distribute only the modified portion created by Licensee, however, any derivative work stemming from the Software or its code must be distributed pursuant to this License, including this Notice provision.

  5.3.  *Recipients as Licensees*: Any individual or entity that uses, copies, modifies, reproduces, distributes, or prepares derivative work based upon the Software, all or part of the Software's code, or a derivative work developed by using the Software, including a portion of its code, is a Licensee as defined above and is subject to the terms and conditions of this License.

6.  **REPRESENTATIONS AND WARRANTIES:**

  6.1.  *Disclaimer of Warranty*: TO THE FULL EXTENT ALLOWED BY LAW, THIS SOFTWARE COMES "AS IS," WITHOUT ANY WARRANTY, EXPRESS OR IMPLIED, AND LICENSOR SHALL NOT BE LIABLE TO ANY PERSON OR ENTITY FOR ANY DAMAGES OR OTHER LIABILITY ARISING FROM, OUT OF, OR IN CONNECTION WITH THE SOFTWARE OR THIS LICENSE, UNDER ANY LEGAL CLAIM.

  6.2.  *Limitation of Liability*: LICENSEE SHALL HOLD LICENSOR HARMLESS AGAINST ANY AND ALL CLAIMS, DEBTS, DUES, LIABILITIES, LIENS, CAUSES OF ACTION, DEMANDS, OBLIGATIONS, DISPUTES, DAMAGES, LOSSES, EXPENSES, ATTORNEYS' FEES, COSTS, LIABILITIES, AND ALL OTHER CLAIMS OF EVERY KIND AND NATURE WHATSOEVER, WHETHER KNOWN OR UNKNOWN, ANTICIPATED OR UNANTICIPATED, FORESEEN OR UNFORESEEN, ACCRUED OR UNACCRUED, DISCLOSED OR UNDISCLOSED, ARISING OUT OF OR RELATING TO LICENSEE'S USE OF THE SOFTWARE. NOTHING IN THIS SECTION SHOULD BE INTERPRETED TO REQUIRE LICENSEE TO INDEMNIFY LICENSOR, NOR REQUIRE LICENSOR TO INDEMNIFY LICENSEE.

7.  **TERMINATION**

  7.1.  *Violations of Ethical Standards or Breaching Duty of Care*: If Licensee violates the Ethical Standards section or Licensee, or any other person or entity within the Supply Chain prior to a good or service reaching the Licensee, breaches its Duty of Care to Supply Chain Impacted Parties, Licensee must remedy the violation or harm caused by Licensee within 30 days of being notified of the violation or harm. If Licensee fails to remedy the violation or harm within 30 days, all rights in the Software granted to Licensee by License will be null and void as between Licensor and Licensee.

  7.2.  *Failure of Notice*: If any person or entity notifies Licensee in writing that Licensee has not complied with the Notice section of this License, Licensee can keep this License by taking all practical steps to comply within 30 days after the notice of noncompliance. If Licensee does not do so, Licensee's License (and all rights licensed hereunder) will end immediately.

  7.3.  *Judicial Findings*: In the event Licensee is found by a civil, criminal, administrative, or other court of competent jurisdiction, or some other adjudicating body with legal authority, to have committed actions which are in violation of the Ethical Standards or Supply Chain Impacted Party sections of this License, all rights granted to Licensee by this License will terminate immediately.

  7.4.  *Patent Litigation*: If Licensee institutes patent litigation against any entity (including a cross-claim or counterclaim in a suit) alleging that the Software, all or part of the Software's code, or a derivative work developed using the Software, including a portion of its code, constitutes direct or contributory patent infringement, then any patent license, along with all other rights, granted to Licensee under this License will terminate as of the date such litigation is filed.

  7.5.  *Additional Remedies*: Termination of the License by failing to remedy harms in no way prevents Licensor or Supply Chain Impacted Party from seeking appropriate remedies at law or in equity.

8.  **MISCELLANEOUS:**

  8.1.  *Conditions*: Sections 3, 4.1, 5.1, 5.2, 7.1, 7.2, 7.3, and 7.4 are conditions of the rights granted to Licensee in the License.

  8.2.  *Equitable Relief*: Licensor and any Supply Chain Impacted Party shall be entitled to equitable relief, including injunctive relief or specific performance of the terms hereof, in addition to any other remedy to which they are entitled at law or in equity.
"""), (Just Copyleft,
 """
  8.3.  (Module -- Copyleft) *Copyleft*: Modified software, source code, or other derivative work must be licensed, in its entirety, under the exact same conditions as this License.
"""), (Nothing,
 """
  8.4.  *Severability*: If any term or provision of this License is determined to be invalid, illegal, or unenforceable by a court of competent jurisdiction, any such determination of invalidity, illegality, or unenforceability shall not affect any other term or provision of this License or invalidate or render unenforceable such term or provision in any other jurisdiction. If the determination of invalidity, illegality, or unenforceability by a court of competent jurisdiction pertains to the terms or provisions contained in the Ethical Standards section of this License, all rights in the Software granted to Licensee shall be deemed null and void as between Licensor and Licensee.

  8.5.  *Section Titles*: Section titles are solely written for organizational purposes and should not be used to interpret the language within each section.

  8.6.  *Citations*: Citations are solely written to provide context for the source of the provisions in the Ethical Standards.

  8.7.  *Section Summaries*: Some sections have a brief *italicized description* which is provided for the sole purpose of briefly describing the section and should not be used to interpret the terms of the License.

  8.8.  *Entire License*: This is the entire License between the Licensor and Licensee with respect to the claims released herein and that the consideration stated herein is the only consideration or compensation to be paid or exchanged between them for this License. This License cannot be modified or amended except in a writing signed by Licensor and Licensee.

  8.9.  *Successors and Assigns*: This License shall be binding upon and inure to the benefit of the Licensor's and Licensee's respective heirs, successors, and assigns.
""")]
